# 'Polemarch' documentation

# Installation

## Install from PyPI

1. Install dependencies:

   Required packages on Ubuntu/Debian:

       sudo apt-get install python3-virtualenv python3.6 python3.6-dev gcc libffi-dev libkrb5-dev libffi6 libssl-dev libyaml-dev libsasl2-dev libldap2-dev default-libmysqlclient-dev sshpass git

   Required packages on Red Hat/CentOS:

       sudo yum install epel-release
       sudo yum install https://$(rpm -E '%{?centos:centos}%{!?centos:rhel}%{rhel}').iuscommunity.org/ius-release.rpm
       sudo yum install python36u python36u-devel python36-virtualenv openssl-devel libyaml-devel krb5-devel krb5-libs openldap-devel mysql-devel git sshpass

2. Create user:

         sudo useradd --user-group --create-home --shell /bin/bash polemarch

     Hint

     You can add this user to sudoers for easer instalation proccess and support.

3. Create virtualenv and activate it:

   >     virtualenv --python=python3.6 /opt/polemarch
   >     sudo chown -R polemarch:polemarch /opt/polemarch
   >     sudo -u polemarch -i
   >     source /opt/polemarch/bin/activate

   > Note

   > If you have more then one Python version, recomended use Python 3.6 and create virtualenv with Py3.6

   > Warning

   > We support Python 2.7 until Polemarch 2.0 release.

4. Install Polemarch:

       pip install -U polemarch mysqlclient

5. Edit config file:

   1. Open /etc/polemarch/settings.ini, if it does not exist, create it. Polemarch uses config from this directory.

   2. The default database is SQLite3, but MariaDB is recommended. Settings needed for correct work MariaDB database:

      >     [database]
      >     engine = django.db.backends.mysql
      >     name = db_name
      >     user = db_user
      >     password = db_password

      >     [database.options]
      >     connect_timeout = 20
      >     init_command = SET sql_mode='STRICT_TRANS_TABLES', default_storage_engine=INNODB, NAMES 'utf8', CHARACTER SET 'utf8', SESSION collation_connection = 'utf8_unicode_ci'

      > Note

      > Set `host` and `port` settings if you connect to remote server.

   3. Create database in MariaDB with this commands:

      >     sudo -H mysql <<QUERY_INPUT
      >     SET @@global.innodb_large_prefix = 1;
      >     create user db_user;
      >     create database db_name default CHARACTER set utf8   default COLLATE utf8_general_ci;
      >     grant all on db_name.* to 'db_user'@'localhost' identified by 'db_password';
      >     QUERY_INPUT

      > Note

      > You should do it on database host if you connect to remote server.

   4. Then, if you use MariaDB and you have set timezone different from “UTC” you should run next command:

      >     mysql_tzinfo_to_sql /usr/share/zoneinfo | sudo -H mysql mysql

      > Note

      > You should do it on database host if you connect to remote server.

   5. The default cache system is file based cache, but RedisCache is recommended. Settings needed for correct RedisCache work:

          [cache]
          backend = django_redis.cache.RedisCache
          location = redis://127.0.0.1:6379/1

          [locks]
          backend = django_redis.cache.RedisCache
          location = redis://127.0.0.1:6379/2

      Note

      Set host ip and port instead of 127.0.0.1:6379 if you connect to remote server.

   6. The default celery broker is file Celery broker, but Redis is recommended. Settings needed for correct Redis work:

          [rpc]
          connection = redis://127.0.0.1:6379/3
          heartbeat = 5
          concurrency = 8
          enable_worker = true

      Note

      Set host ip and port instead of 127.0.0.1:6379 if you connect to remote server.

      Hint

      Use RabbitMQ in case there can be a big network delay between the Polemarch nodes.

   7. Create directory for log and pid files:

          mkdir /opt/polemarch/logs /opt/polemarch/pid

   8. For running Polemarch with worker, you need to create follow sections:

          [uwsgi]
          processes = 4
          threads = 4
          harakiri = 120
          vacuum = True
          pidfile = /opt/polemarch/pid/polemarch.pid
          log_file = /opt/polemarch/logs/{PROG_NAME}_web.log

          [worker]
          # output will be /opt/polemarch/logs/polemarch_worker.log
          logfile = /opt/polemarch/logs/{PROG_NAME}_worker.log
          # output will be /opt/polemarch/pid/polemarch_worker.pid
          pidfile = /opt/polemarch/pid/{PROG_NAME}_worker.pid
          loglevel = INFO

      Also if you need to set your own path for logfile or pidfile, different from the path from example, you can do it, but make sure, that user, which starts Polemarch has write-permissions for these directory and file. If you run it as root, we recommend to add in ``[uwsig]`` params ``uid`` and ``gid`` (read more).

      Tip

      More configuration settings you can find in Configuration manual.

6. Make migrations:

       polemarchctl migrate

7. Start Polemarch:

       polemarchctl webserver

Polemarch starts with web interface on port 8080.

If you need to restart Polemarch use following command:

>     polemarchctl webserver reload=/opt/polemarch/pid/polemarch.pid

If you use another directory for storing Polemarch pid file, use path to this file.

If you need to stop Polemarch use following command:

>     polemarchctl webserver stop=/opt/polemarch/pid/polemarch.pid

If you use another directory for storing Polemarch pid file, use path to this file.

## Quickstart

After you install Polemarch by instructions above you can use it without any further configuration. Interface is pretty intuitive and common for any web application. Read more in GUI workflow documentation.

Default installation is suitable for most simple and common cases, but Polemarch is highly configurable system. If you need something more advanced (scalability, dedicated DB, custom cache, logging or directories) you can always configure Polemarch like it is said in Configuration manual.

## Backup

Regular uploading of backups is a guarantee of the reliability of the application. We recomended use SQL backup or copy database.

There are examples of SQL backup for MySQL and PostgreSQL below.

Making backup in MySQL:

>     shell> mysqldump dbname > dump.sql

Here dbname is the name of your database, dump.sql is the file, where all SQL backup statements will be saved.

Uploading of backup in MySQL:

>     shell> mysqladmin create dbname
>     shell> mysql dbname < dump.sql

Making backup in PostgreSQL:

>     pg_dump dbname > dump.sql

Uploading of backup in PostgreSQL:

>     createdb dbname
>     psql dbname < dump.sql

## Update

Before updating of package of any type it is strongly recommended to stop all services and create backup for safety.

## Update from any old version

1. Firstly, we strongly recommend you to create a database backup and to stop all Polemarch services for safety.
2. Secondly, if you are updating from 0.x.y to 1.x.y, you need to update you current 0.x.y version to 1.0.0 version.
3. Then update to the latest version. If you don’t know how to do it, look “Install from PyPI”.

## Migrate

Migrations are Django’s way of propagating changes you make to your models (adding a field, deleting a model, etc.) into your database schema. They’re designed to be mostly automatic, but you need to know when to make migrations, when to run them, and the common problems you might run into.

To run a `migrate` command you should run follow code:

    polemarchctl migrate

## Create superuser

A superuser is the user, who has all permissions.

To create a superuser account use the follow command:

    polemarchctl createsuperuser

This command prompts for all required user’s options.

## Change password

To change password use the follow command:

    polemarchctl changepassword [<username>]

It prompts you to enter a new password twice for the given user. If the entries are identical, this immediately becomes the new password. If you do not supply a user, the command will attempt to change the password of user whose username matches the current user.